@@ -30,7 +30,8 @@ sub new {
     my @bind;
 
     my @columns =
-      map { $self->_prepare_column($_, $self->{from}, \@bind) } @{$self->{columns}};
+      map { $self->_prepare_column($_, $self->{from}, \@bind) }
+      @{$self->{columns}};
     push @columns, $self->_collect_columns_from_joins($self->{join});
 
     $sql .= 'SELECT ';
@@ -63,12 +64,18 @@ sub new {
         }
     }
 
-    if (my $group_by = $params{group_by}) {
-        $group_by =
-          ref($group_by)
-          ? $$group_by
-          : $self->_quote($group_by, $self->{from});
-        $sql .= ' GROUP BY ' . $group_by;
+    if (my $group_bys = $params{group_by}) {
+        $group_bys = [$group_bys] unless ref $group_bys eq 'ARRAY';
+
+        my @group_by;
+        foreach my $group_by (@$group_bys) {
+            push @group_by,
+              ref($group_by)
+              ? $$group_by
+              : $self->_quote($group_by, $self->{from});
+        }
+
+        $sql .= ' GROUP BY ' . join(', ', @group_by);
     }
 
     if (my $order_by = $params{order_by}) {
@@ -154,10 +161,10 @@ sub _prepare_column {
                     if (ref $$value eq 'ARRAY') {
                         my $sql = $$value->[0];
                         push @$bind, @$$value[1 .. $#{$$value}];
-                        $sql
+                        $sql;
                     }
                     else {
-                        $$value
+                        $$value;
                     }
                   }
               )
@@ -196,20 +203,15 @@ sub _populate_joins {
     my ($set, $row, $joins) = @_;
 
     foreach my $join (@$joins) {
-        my $join_source = $join->{as} || $join->{source};
+        my $join_source = $join->{rel_name} || $join->{as} || $join->{source};
 
         $set->{$join_source} ||= {};
         $self->_populate($set->{$join_source}, $row, $join->{columns});
 
         if (my $subjoins = $join->{join}) {
             $subjoins = [$subjoins] unless ref $subjoins eq 'ARRAY';
-            foreach my $subjoin (@$subjoins) {
-                my $subjoin_source = $subjoin->{as} || $subjoin->{source};
 
-                $set->{$join_source}->{$subjoin_source} ||= {};
-                $self->_populate($set->{$join_source}->{$subjoin_source},
-                    $row, $subjoin->{columns});
-            }
+            $self->_populate_joins($set->{$join_source}, $row, $subjoins);
         }
     }
 }
